Learn R Programming

tradestatistics (version 3.0.2)

ots_commodities: A table of official commodity names from the Harmonized System rev 2007 (HS07, also known as H3)

Description

Provides official commodity, group and section codes and names taken from the United Nations official sources. This data is used by the functions provided within this package to complement the data obtained from the API.

Usage

ots_commodities

Arguments

Format

A data frame with 5151 observations on the following 6 variables.

commodity_code

Code of every commodity (e.g. 010110)

commodity_fullname_english

HS commodity names (e.g. 'Horses, asses, mules and hinnies; live, pure-bred breeding animals')

group_code

Group code (e.g. 01)

group_fullname_english

Group name (e.g. 'Animals; live')

section_code

Section code (e.g. 01)

section_fullname_english

Section name (e.g. 'Live animals and animal products')

Examples

Run this code
ots_commodities

Run the code above in your browser using DataLab