Learn R Programming

tradestatistics (version 4.5.0)

ots_distances: OTS Distances

Description

Distance between countries, alongside colonial relation, common language, and continuity.

Usage

ots_distances

Arguments

Format

A data frame with 22,791 rows and 8 variables

  • country1First ISO-3 code in the dyad (alphabetical order)

  • country2Second ISO-3 code in the dyad (alphabetical order)

  • distDistance between most populated cities (in kilometers)

  • distcapDistance between capitals (in kilometers)

  • colonyVariable coded as 1 when the two countries are or were in a colonial relation

  • comlang_ethnoVariable coded as 1 when the two countries have at least 9% of their population speaking the same language

  • comlang_offVariable coded as 1 when the two countries share the same official language

  • contigVariable coded as 1 when the two countries are next to each other and 0 otherwise