Year to year GDP deflator some of the countries in the OTS database. For countries not available in the World Bank database, rows labelled as "wld" are provided, which were computed as the weighted median for each year using the GDP of listed countries for each year expressed as constant dollars of the year 2010.
ots_gdp_deflatorA data frame with 7,238 observations on the following 4 variables
country_isoISO code of the country (e.g. "chl" means Chile)
fromInteger values in the range 1980-2018
toInteger values in the range 1981-2019
gdp_deflatorNumeric value expressed as one plus 1-year deflator