Learn R Programming

tradestatistics (version 1.1)

ots_products_shortnames: A table of unofficial shortened product names

Description

Provides shortened product names obtained from The Observatory of Economic Complexity. This data corresponds to a modified version of unofficial short names created for 4 digits HS codes.

Usage

ots_products_shortnames

Arguments

Format

A data frame with 1222 observations on the following 2 variables.

product_code

Code of every product (e.g. 0101)

product_shortname_english

Unofficial product names (e.g. Horses)

Examples

Run this code
# NOT RUN {
ots_products_shortnames
# }

Run the code above in your browser using DataLab