Learn R Programming

tradestatistics (version 3.0.2)

ots_sections_colors: A table of official section names from the Harmonized System rev 2007 (HS07, also known as H3) and unofficial colors to ease visualization

Description

Provides official section names taken from the United Nations official sources but the colors are absolutely unofficial and based of what I consider a good palette for 22 sections (21 + 1 for unspecified products). This data is not used by the functions provided within this package and is provided as reference.

Usage

ots_sections_colors

Arguments

Format

A data frame with 22 observations on the following 2 variables.

section_fullname_english

Section name (e.g. 'Live animals and animal products')

section_color

Section hex color (e.g. "#74c0e2")

Examples

Run this code
ots_sections_colors

Run the code above in your browser using DataLab