Learn R Programming

tradestatistics (version 1.1)

ots_sections_shortnames: A table of sections codes and shortened names associated to products

Description

Provides shortened section names from The Atlas of Economic Complexity (Harvard), which are simplified names after official HS sections but keeping the same codes.

Usage

ots_sections

Arguments

Format

A data frame with 22 observations on the following 2 variables.

section_code

Section code (e.g. 01)

section_shortname_english

Section name (e.g. Animal Products)

Examples

Run this code
# NOT RUN {
ots_sections_shortnames
# }

Run the code above in your browser using DataLab