ots_commodities: A table of official commodity names from the Harmonized System rev 2007
(HS07, also known as H3)
Description
Provides official commodity, group and section codes and names taken from the
United Nations official sources. This data is used by the functions provided
within this package to complement the data obtained from the API.
Usage
ots_commodities
Arguments
Format
A data frame with 5151 observations on the following 6 variables.