Learn R Programming

tradestatistics (version 6.0.0)

ots_countries: OTS Countries

Description

Official country names, ISO-3 codes, continent and EU membership.

Usage

ots_countries

Arguments

Format

A data frame with 275 observations on the following 5 variables

country_iso

ISO-3 code of the country (e.g. "GBR")

country_name

Country name (e.g. United Kingdom)

continent_id

Numeric id of the continent where the country belongs to (e.g., 4)

continent_name

Continent where the country belongs to (e.g., Europe)

continent_color

Color assigned to each continent for visualization purposes (e.g., '#8abdb6')