Official country names, ISO-3 codes, continent and EU membership.
ots_countriesA data frame with 275 observations on the following 5 variables
country_isoISO-3 code of the country (e.g. "GBR")
country_nameCountry name (e.g. United Kingdom)
continent_idNumeric id of the continent where the country belongs to (e.g., 4)
continent_nameContinent where the country belongs to (e.g., Europe)
continent_colorColor assigned to each continent for visualization purposes (e.g., '#8abdb6')