Provides official codes taken from the United Nations official sources.
This data is used by the functions provided within this package to validate
user parameters and add both product and country text columns to the data,
therefore reducing the number of API calls and the time to generate the
requested data.