Learn R Programming

tradestatistics (version 3.0.2)

ots_inflation: A table with world weigthed mean inflation since 2000

Description

Provides year to year inflations value to be applied as a conversion rate to express dollars of year Y1 as dollars of year Y2. This dataset is provided to be used with ots_inflation_adjustment that converts units forwards and backwards in time.

Usage

data("ots_inflation")

Arguments

Format

A data frame with 20 observations on the following 3 variables.

from

Integer values in the range 2000-2019

to

Integer values in the range 2001-2020

conversion_factor

Numeric value expressed as one plus 1-year inflation

Examples

Run this code
ots_inflation

Run the code above in your browser using DataLab