Learn R Programming

tradestatistics (version 1.1)

ots_product_section: String matching of official product section names and product section codes

Description

Takes a text string and searches within the package data for all matching product communities in the context of valid API product communities

Usage

ots_product_section(productsection = NULL)

Arguments

productsection

A text string such as "animals", or "FOODSTUFFS".

Value

A tibble with all possible matches (no uppercase distinction) showing the section name and section code

Examples

Run this code
# NOT RUN {
ots_product_section(productsection = "  Animals")
ots_product_section(productsection = "FABRIC ")
# }

Run the code above in your browser using DataLab