powered by
Takes a text string and searches within the package data for all matching product communities in the context of valid API product communities
ots_product_section(productsection = NULL)
A text string such as "animals", or "FOODSTUFFS".
A tibble with all possible matches (no uppercase distinction) showing the section name and section code
# NOT RUN { ots_product_section(productsection = " Animals") ots_product_section(productsection = "FABRIC ") # }
Run the code above in your browser using DataLab