Learn R Programming

tradestatistics (version 1.1)

ots_products: A table of official product names from the Harmonized System (HS)

Description

Provides official codes taken from the United Nations official sources. This data is provided as a reference as it's not used by the functions provided within this package, but it can be useful to subset the data obtained from the API.

Usage

ots_products

Arguments

Format

A data frame with 1320 observations on the following 2 variables.

product_code

Code of every product (e.g. 0101)

product_fullname_english

HS product names (e.g. 'Horses, asses, mules and hinnies; live')

Examples

Run this code
# NOT RUN {
ots_products
# }

Run the code above in your browser using DataLab